# HIVE-001: Low test coverage

- id: HIVE-001
- status: proposed
- title: Low test coverage
- priority: critical
- created: 2026-02-15T00:26:35.675183+00:00
- source: advisor

## Problem
2 test files for 30 source files (7%)

## Solution
Requires manual analysis -- LLM proposal generation failed.

## Files
- Modify: 
- Create: 

## Estimates
- Impact: 5
- Effort: 3 days
- Risk: medium

## Rollback
Revert the PR
